Affected by GO-2026-5145
and 3 other vulnerabilities
GO-2026-5145: Oxia affected by server crash via race condition in session heartbeat handling in github.com/oxia-db/oxia
GO-2026-5226: Oxia's TLS CA certificate chain validation fails with multi-certificate PEM bundles in github.com/oxia-db/oxia
GO-2026-5364: Oxia has an OIDC token audience validation bypass via SkipClientIDCheck in github.com/oxia-db/oxia
GO-2026-5546: Oxia exposes bearer token in debug log messages on authentication failure in github.com/oxia-db/oxia
package
Version:
v0.14.1
Opens a new window with list of versions in this module.
Published: Jun 30, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
RemoveFileIfExists removes the file, it will return nil if the file does not exist.
BitSet
Simplified and compact bitset.
type Sender[U any] interface {
Send(message *U) error
}
type Stream[T any] interface {
Recv() (*T, error)
}
type StreamReader interface {
Run() error
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.